MismatchDocMut

Trait MismatchDocMut 

pub trait MismatchDocMut<T> {
    // Required method
    fn apply_mut(
        &self,
        input: &mut T,
        fail_fast: bool,
    ) -> Result<Vec<DocError>, DocError>;
}
document update as mutation

Required Methods

fn apply_mut( &self, input: &mut T, fail_fast: bool, ) -> Result<Vec<DocError>, DocError>

if fail_fast then stop on first error, otherwise try to apply all and collect errors on Ok response

  • non-transactional behavioral, partial updates possible either on fail_fast!

Implementors