pub trait MismatchDocMut<T> { // Required method fn apply_mut( &self, input: &mut T, fail_fast: bool, ) -> Result<Vec<DocError>, DocError>; }
document update as mutation
if fail_fast then stop on first error, otherwise try to apply all and collect errors on Ok response